#ifndef _H_CONSOLE
#define _H_CONSOLE

/*
 * console.h
 *
 * Interface between console.c and low-level console device drivers
 * (vga.c, tga.c, etc)
 *
 *  Copyright (C) 1996 Erik Troan
 *	
 */

#ifdef CONFIG_TGA_CONSOLE

extern void tga_set_cursor(int currcons);
extern void tga_hide_cursor(void);
extern unsigned long tga_init(unsigned long, const char **);
extern int  tga_set_get_cmap(unsigned char *, int);
extern int  tga_set_get_font(char *, int, int);
extern void tga_get_scrmem(int currcons);
extern void tga_vesa_blank(void);
extern void tga_vesa_unblank(void);
extern void tga_vesa_powerdown(void);
extern void tga_set_vesa_blanking(const unsigned long arg);
extern void tga_set_palette(void);
extern void tga_set_scrmem(int currcons, long offset);
extern void tga_set_origin(unsigned short);
extern int  tga_adjust_height(unsigned long);
extern int  tga_blitc(unsigned int, unsigned long);

#endif

#if (!defined(__alpha__)) || defined(CONFIG_VGA_CONSOLE)

extern void vga_set_cursor(int currcons);
extern void vga_hide_cursor(void);
extern unsigned long vga_init(unsigned long, const char **);
extern int  vga_set_get_cmap(unsigned char *, int);
extern int  vga_set_get_font(char *, int, int);
extern void vga_get_scrmem(int currcons);
extern void vga_vesa_blank(void);
extern void vga_vesa_unblank(void);
extern void vga_vesa_powerdown(void);
extern void vga_set_vesa_blanking(const unsigned long arg);
extern void vga_set_palette(void);
extern void vga_set_scrmem(int currcons, long offset);
extern void vga_set_origin(unsigned short);
extern int  vga_adjust_height(unsigned long);

#endif

#ifdef CONFIG_TGA_CONSOLE
# ifdef CONFIG_VGA_CONSOLE

/* here we TGA and VGA together via dispatch table */

struct console_desc {
    char * name;
    void (* set_cursor)(int currcons);
    void (* hide_cursor)(void);
    unsigned long (* init)(unsigned long, const char **);
    int (* set_get_cmap)(unsigned char *, int);
    int (* set_get_font)(char *, int, int);
    void (* get_scrmem)(int currcons);
    void (* vesa_blank)(void);
    void (* vesa_unblank)(void);
    void (* vesa_powerdown)(void);
    void (* set_vesa_blanking)(const unsigned long arg);
    void (* set_palette)(void);
    void (* set_scrmem)(int currcons, long offset);
    int (* adjust_height)(unsigned long fontheight);
    void (* set_origin)(unsigned short where);
    int (* blitc)(unsigned int charattr, unsigned long addr);
}; 

#define set_cursor		cons_devices[curr_cons].set_cursor
#define hide_cursor		cons_devices[curr_cons].hide_cursor
#define con_type_init		cons_devices[curr_cons].init
#define set_get_cmap		cons_devices[curr_cons].set_get_cmap
#define set_get_font		cons_devices[curr_cons].set_get_font
#define get_scrmem		cons_devices[curr_cons].get_scrmem
#define vesa_blank		cons_devices[curr_cons].vesa_blank
#define vesa_unblank		cons_devices[curr_cons].vesa_unblank
#define vesa_powerdown		cons_devices[curr_cons].vesa_powerdown
#define set_vesa_blanking	cons_devices[curr_cons].set_vesa_blanking
#define set_palette		cons_devices[curr_cons].set_palette
#define set_scrmem		cons_devices[curr_cons].set_scrmem
#define __set_origin		cons_devices[curr_cons].set_origin
#define con_adjust_height	cons_devices[curr_cons].adjust_height
#define con_blitc		cons_devices[curr_cons].blitc

# else /* VGA */

/* here is TGA only */

#define set_cursor		tga_set_cursor
#define hide_cursor		tga_hide_cursor
#define con_type_init		tga_init
#define set_get_cmap		tga_set_get_cmap
#define set_get_font		tga_set_get_font
#define get_scrmem		tga_get_scrmem
#define vesa_blank		tga_vesa_blank
#define vesa_unblank		tga_vesa_unblank
#define vesa_powerdown		tga_vesa_powerdown
#define set_vesa_blanking	tga_set_vesa_blanking
#define set_palette		tga_set_palette
#define set_scrmem		tga_set_scrmem
#define __set_origin		tga_set_origin
#define con_adjust_height	tga_adjust_height
#define con_blitc		tga_blitc

# endif /* VGA */

#else /* TGA */

/* here is VGA only */

#define set_cursor		vga_set_cursor
#define hide_cursor		vga_hide_cursor
#define con_type_init		vga_init
#define set_get_cmap		vga_set_get_cmap
#define set_get_font		vga_set_get_font
#define get_scrmem		vga_get_scrmem
#define vesa_blank		vga_vesa_blank
#define vesa_unblank		vga_vesa_unblank
#define vesa_powerdown		vga_vesa_powerdown
#define set_vesa_blanking	vga_set_vesa_blanking
#define set_palette		vga_set_palette
#define set_scrmem		vga_set_scrmem
#define __set_origin		vga_set_origin
#define con_adjust_height	vga_adjust_height

#endif /* TGA */
#endif /* _H_CONSOLE */
